<?php

namespace App\Classes\FTN\Process\Netmail\Robot\Areafix;

use Illuminate\Support\Facades\Log;

use App\Jobs\AreafixRescan;

// RESCAN - Resend echomail
class Rescan extends Base
{
	private const LOGKEY = 'AFR';
	private const command = '%RESCAN';

	public static function help(): array
	{
		return [
			self::command.' [-|+]<ECHOAREA> [<DAYS>]',
			'   Use the rescan command to resend mail from an echoarea.',
			'   This is will resend mail again, even if you have received it in the past.',
			'   Arguments:',
			'   - ECHOAREA (required) name of area to subscribe or unsubscribe',
			'   - DAYS (optional) number of days to resend mail from this area that you',
			'     If DAYS is omitted, the default is 30',
		];
	}

	public function process(): string
	{
		Log::debug(sprintf('%s:- Areafix [%s] for [%s] for [%s]',self::LOGKEY,self::command,$this->mo->fftn->ftn,join('|',$this->arguments)));

		$command = self::command.' '.join(' ',$this->arguments);

		if (! is_numeric($this->arguments[1]))
			return sprintf('%-25s <-- INVALID, DAYS [%s] NOT NUMERIC',$command,$this->arguments[1]);

		// Area exists
		if ($ea=$this->mo->fftn->domain->echoareas->where('name',$this->arguments[0])->pop()) {
			// If already subscribed
			if ($this->mo->fftn->echoareas->pluck('name')->contains($this->arguments[0])) {
				AreafixRescan::dispatch($this->mo->fftn,$ea,$this->arguments[1],TRUE)
					->onQueue('mail');

				Log::debug(sprintf('%s:- FTN [%s] RESCAN [%s] DAYS [%d]',self::LOGKEY,$this->mo->fftn->ftn,$this->arguments[0],$this->arguments[1]));

				return sprintf('%-25s <-- RESCAN [%d] DAYS queued',$command,$this->arguments[1]);

			// If not subscribed
			} else {
				Log::debug(sprintf('%s:- FTN [%s] is NOT subscribed to [%s], NO ACTION taken',self::LOGKEY,$this->mo->fftn->ftn,$this->arguments[0]));

				return sprintf('%-25s <-- NOT subscribed, NO ACTION taken',$command);
			}

		} else {
			Log::debug(sprintf('%s:- FTN [%s] area UNKNOWN [%s], NO ACTION taken',self::LOGKEY,$this->mo->fftn->ftn,$this->arguments[0]));

			return sprintf('%-25s <-- AREA UNKNOWN, NO ACTION TAKEN',$command);
		}
	}
}