<?php

namespace App\Notifications\Netmails;

use Illuminate\Support\Facades\Log;

use App\Notifications\Netmails;
use App\Models\Netmail;
use App\Traits\{MessagePath,PageTemplate};

class FixCantHandle extends Netmails
{
	use MessagePath,PageTemplate;

	private const LOGKEY = 'NAF';

	private Netmail $mo;

	/**
	 * Reply to an areafix request.
	 *
	 * @param Netmail $mo
	 */
	public function __construct(Netmail $mo)
	{
		parent::__construct();

		$this->mo = $mo;
	}

	/**
	 * Get the mail representation of the notification.
	 *
	 * @param mixed $notifiable
	 * @return Netmail
	 * @throws \Exception
	 */
	public function toNetmail(object $notifiable): Netmail
	{
		$o = $this->setupNetmail($notifiable);
		$ao = $notifiable->routeNotificationFor(static::via);

		Log::info(sprintf('%s:+ Responding to *fix with netmail to [%s]',self::LOGKEY,$ao->ftn));

		$o->to = $this->mo->from;
		$o->replyid = $this->mo->msgid;
		$o->subject = '*fix Reply';

		// Message
		$msg = $this->page(FALSE,$this->mo->to);

		$msg->addText("Your *fix request has been received, but unfortunately I do not know how to handle this *fix message yet.\r\r");
		$msg->addText(sprintf("Until then, you may be able to achieve what you want via the web UI. Head over to %s. Feel free to netmail if you need help.\r\r",config('app.url')));

		$msg->addText($this->message_path($this->mo));

		$o->msg = $msg->render();
		$o->set_tagline = 'Why did the robot cross the road? The chicken programmed it.';

		$o->save();

		return $o;
	}
}